@@ -1,44 +1,45 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2014 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2014 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
-Script for eric6 to clean up the source tree.
+Script for eric to clean up the source tree.
 """
 
-import os
-import sys
 import fnmatch
+import os
 import shutil
+import sys
 
 
 def cleanupSource(dirName):
     """
     Cleanup the sources directory to get rid of leftover files
     and directories.
-    
+
     @param dirName name of the directory to prune (string)
     """
     # step 1: delete all Ui_*.py files without a corresponding
     #         *.ui file
     dirListing = os.listdir(dirName)
     for formName, sourceName in [
-        (f.replace('Ui_', "").replace(".py", ".ui"), f)
-            for f in dirListing if fnmatch.fnmatch(f, "Ui_*.py")]:
+        (f.replace("Ui_", "").replace(".py", ".ui"), f)
+        for f in dirListing
+        if fnmatch.fnmatch(f, "Ui_*.py")
+    ]:
         if not os.path.exists(os.path.join(dirName, formName)):
             os.remove(os.path.join(dirName, sourceName))
             if os.path.exists(os.path.join(dirName, sourceName + "c")):
                 os.remove(os.path.join(dirName, sourceName + "c"))
-    
+
     # step 2: delete the __pycache__ directory and all remaining *.pyc files
     if os.path.exists(os.path.join(dirName, "__pycache__")):
         shutil.rmtree(os.path.join(dirName, "__pycache__"))
-    for name in [f for f in os.listdir(dirName)
-                 if fnmatch.fnmatch(f, "*.pyc")]:
+    for name in [f for f in os.listdir(dirName) if fnmatch.fnmatch(f, "*.pyc")]:
         os.remove(os.path.join(dirName, name))
-    
+
     # step 3: descent into subdirectories and delete them if empty
     for name in os.listdir(dirName):
         name = os.path.join(dirName, name)
@@ -57,8 +58,8 @@ def main(argv):
     print("Cleaning up source ...")
     sourceDir = os.path.dirname(os.path.dirname(__file__)) or "."
     cleanupSource(sourceDir)
-    
-    
+
+
 if __name__ == "__main__":
     try:
         main(sys.argv)
@@ -68,7 +69,8 @@ if __name__ == "__main__":
         print(
             "\nAn internal error occured.  Please report all the output of the"
             " program, \nincluding the following traceback, to"
-            " eric-bugs@eric-ide.python-projects.org.\n")
+            " eric-bugs@eric-ide.python-projects.org.\n"
+        )
         raise
 
 #
