@@ -1,23 +1,24 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2021 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
-Script for eric6 to compile all .ui files to Python source.
+Script for eric to compile all .ui files to Python source.
 """
 
+import os
 import sys
 
-from PyQt5.uic import compileUiDir
+from PyQt6.uic import compileUiDir
 
 
 def __pyName(py_dir, py_file):
     """
     Local function to create the Python source file name for the compiled
     .ui file.
-    
+
     @param py_dir suggested name of the directory (string)
     @param py_file suggested name for the compile source file (string)
     @return tuple of directory name (string) and source file name (string)
@@ -29,7 +30,14 @@ def compileUiFiles():
     """
     Compile the .ui files to Python sources.
     """
-    compileUiDir("eric6", True, __pyName)
+    if os.path.exists("src"):
+        # eric7 with 'src' layout
+        compileUiDir(os.path.join("src", "eric7"), recurse=True, map=__pyName)
+    elif os.path.exists("eric7"):
+        # old layout or invoked from within 'src'
+        compileUiDir("eric7", recurse=True, map=__pyName)
+    else:
+        print("No valid 'eric7' source layout could be found. Aborting...")
 
 
 def main(argv):
@@ -41,8 +49,8 @@ def main(argv):
     # Compile .ui files
     print("Compiling user interface files...")
     compileUiFiles()
-    
-    
+
+
 if __name__ == "__main__":
     try:
         main(sys.argv)
@@ -52,7 +60,8 @@ if __name__ == "__main__":
         print(
             "\nAn internal error occured.  Please report all the output of the"
             " program, \nincluding the following traceback, to"
-            " eric-bugs@eric-ide.python-projects.org.\n")
+            " eric-bugs@eric-ide.python-projects.org.\n"
+        )
         raise
 
 #
