@@ -1,67 +1,68 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2020 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2023 Detlev Offenbach <detlev@die-offenbachs.de>
 #
-# This is the uninstall script for eric6.
+# This is the uninstall script for eric.
 #
 
 """
-Uninstallation script for the eric6 IDE and all eric6 related tools.
+Uninstallation script for the eric IDE and all eric related tools.
 """
 
-import sys
+import contextlib
+import getopt
+import glob
 import os
 import shutil
-import glob
-import distutils.sysconfig
+import sys
+import sysconfig
 
 # Define the globals.
 progName = None
 currDir = os.getcwd()
 pyModDir = None
-progLanguages = ["Python", "Ruby", "QSS"]
-defaultMacAppBundleName = "eric6.app"
+progLanguages = ["MicroPython", "Python3", "QSS"]
+defaultMacAppBundleName = "eric7.app"
 defaultMacAppBundlePath = "/Applications"
-settingsNameOrganization = "Eric6"
-settingsNameGlobal = "eric6"
+settingsNameOrganization = "Eric7"
+settingsNameGlobal = "eric7"
 
 
 def exit(rcode=0):
     """
     Exit the uninstall script.
-    
+
     @param rcode result code to report back (integer)
     """
     global currDir
-    
-    # restore the local eric6config.py
-    if os.path.exists("eric6config.py.orig"):
-        if os.path.exists("eric6config.py"):
-            os.remove("eric6config.py")
-        os.rename("eric6config.py.orig", "eric6config.py")
-    
+
+    # restore the local eric7config.py
+    if os.path.exists("eric7config.py.orig"):
+        if os.path.exists("eric7config.py"):
+            os.remove("eric7config.py")
+        os.rename("eric7config.py.orig", "eric7config.py")
+
     if sys.platform.startswith(("win", "cygwin")):
-        try:
-            input("Press enter to continue...")         # secok
-        except (EOFError, SyntaxError):
-            pass
-    
+        with contextlib.suppress(EOFError):
+            input("Press enter to continue...")  # secok
+
     os.chdir(currDir)
-    
+
     sys.exit(rcode)
 
-# get a local eric6config.py out of the way
-if os.path.exists("eric6config.py"):
-    os.rename("eric6config.py", "eric6config.py.orig")
+
+# get a local eric7config.py out of the way
+if os.path.exists("eric7config.py"):
+    os.rename("eric7config.py", "eric7config.py.orig")
 try:
-    from eric6config import getConfig
+    from eric7.Globals import getConfig
 except ImportError:
-    print("The eric6 IDE doesn't seem to be installed. Aborting.")
+    print("The eric IDE doesn't seem to be installed. Aborting.")
     exit(1)
 except SyntaxError:
     # an incomplete or old config file was found
-    print("The eric6 IDE seems to be installed incompletely. Aborting.")
+    print("The eric IDE seems to be installed incompletely. Aborting.")
     exit(1)
 
 
@@ -87,22 +88,22 @@ def initGlobals():
     """
     global pyModDir
 
-    pyModDir = distutils.sysconfig.get_python_lib(True)
+    pyModDir = sysconfig.get_path("platlib")
 
 
 def wrapperNames(dname, wfile):
     """
     Create the platform specific names for the wrapper script.
-    
+
     @param dname name of the directory to place the wrapper into
     @param wfile basename (without extension) of the wrapper script
     @return the names of the wrapper scripts
     """
-    if sys.platform.startswith(("win", "cygwin")):
-        wnames = (dname + "\\" + wfile + ".cmd",
-                  dname + "\\" + wfile + ".bat")
-    else:
-        wnames = (dname + "/" + wfile, )
+    wnames = (
+        (dname + "\\" + wfile + ".cmd", dname + "\\" + wfile + ".bat")
+        if sys.platform.startswith(("win", "cygwin"))
+        else (dname + "/" + wfile,)
+    )
 
     return wnames
 
@@ -112,39 +113,52 @@ def uninstallEric():
     Uninstall the eric files.
     """
     global pyModDir
-    
+
     # Remove the menu entry for Linux systems
     if sys.platform.startswith("linux"):
         uninstallLinuxSpecifics()
     # Remove the Desktop and Start Menu entries for Windows systems
     elif sys.platform.startswith(("win", "cygwin")):
         uninstallWindowsLinks()
-    
+
     # Remove the wrapper scripts
     rem_wnames = [
-        "eric6_api", "eric6_compare",
-        "eric6_configure", "eric6_diff",
-        "eric6_doc", "eric6_qregularexpression",
-        "eric6_qregexp", "eric6_re",
-        "eric6_trpreviewer", "eric6_uipreviewer",
-        "eric6_unittest", "eric6",
-        "eric6_tray", "eric6_editor",
-        "eric6_plugininstall", "eric6_pluginuninstall",
-        "eric6_pluginrepository", "eric6_sqlbrowser",
-        "eric6_iconeditor", "eric6_snap", "eric6_hexeditor",
-        "eric6_browser", "eric6_shell",
-        # from Python2 era
-        "eric6_webbrowser",
+        "eric7_api",
+        "eric7_browser",
+        "eric7_compare",
+        "eric7_configure",
+        "eric7_diff",
+        "eric7_doc",
+        "eric7_editor",
+        "eric7_hexeditor",
+        "eric7_iconeditor",
+        "eric7_ide",
+        "eric7_plugininstall",
+        "eric7_pluginrepository",
+        "eric7_pluginuninstall",
+        "eric7_qregularexpression",
+        "eric7_re",
+        "eric7_shell",
+        "eric7_snap",
+        "eric7_sqlbrowser",
+        "eric7_testing",
+        "eric7_tray",
+        "eric7_trpreviewer",
+        "eric7_uipreviewer",
+        "eric7_virtualenv",
+        # obsolete scripts below
+        "eric7_unittest",
+        "eric7",
     ]
-    
+
     try:
         for rem_wname in rem_wnames:
-            for rwname in wrapperNames(getConfig('bindir'), rem_wname):
+            for rwname in wrapperNames(getConfig("bindir"), rem_wname):
                 if os.path.exists(rwname):
                     os.remove(rwname)
-        
+
         # Cleanup our config file(s)
-        for name in ['eric6config.py', 'eric6config.pyc', 'eric6.pth']:
+        for name in ["eric7config.py", "eric7config.pyc", "eric7.pth"]:
             e5cfile = os.path.join(pyModDir, name)
             if os.path.exists(e5cfile):
                 os.remove(e5cfile)
@@ -152,52 +166,75 @@ def uninstallEric():
             path, ext = os.path.splitext(e5cfile)
             for f in glob.glob("{0}.*{1}".format(path, ext)):
                 os.remove(f)
-        
+
         # Cleanup the install directories
-        for name in ['ericExamplesDir', 'ericDocDir', 'ericDTDDir',
-                     'ericCSSDir', 'ericIconDir', 'ericPixDir',
-                     'ericTemplatesDir', 'ericCodeTemplatesDir',
-                     'ericOthersDir', 'ericStylesDir', 'ericDir']:
-            dirpath = getConfig(name)
-            if os.path.exists(dirpath):
-                shutil.rmtree(dirpath, True)
-        
+        for name in [
+            "ericExamplesDir",
+            "ericDocDir",
+            "ericDTDDir",
+            "ericCSSDir",
+            "ericIconDir",
+            "ericPixDir",
+            "ericTemplatesDir",
+            "ericCodeTemplatesDir",
+            "ericOthersDir",
+            "ericStylesDir",
+            "ericThemesDir",
+            "ericDir",
+        ]:
+            with contextlib.suppress(AttributeError):
+                dirpath = getConfig(name)
+                if os.path.exists(dirpath):
+                    shutil.rmtree(dirpath, True)
+
         # Cleanup translations
         for name in glob.glob(
-                os.path.join(getConfig('ericTranslationsDir'), 'eric6_*.qm')):
+            os.path.join(getConfig("ericTranslationsDir"), "eric7_*.qm")
+        ):
             if os.path.exists(name):
                 os.remove(name)
-        
+
         # Cleanup API files
-        apidir = getConfig('apidir')
+        apidir = getConfig("apidir")
         if apidir:
             for progLanguage in progLanguages:
-                for name in getConfig('apis'):
+                for name in getConfig("apis"):
+                    # step 1: programming language as given
+                    apiname = os.path.join(apidir, progLanguage, name)
+                    if os.path.exists(apiname):
+                        os.remove(apiname)
+                    # step 2: programming language as lowercase
                     apiname = os.path.join(apidir, progLanguage.lower(), name)
                     if os.path.exists(apiname):
                         os.remove(apiname)
                 for apiname in glob.glob(
-                        os.path.join(apidir, progLanguage.lower(), "*.bas")):
-                    if os.path.basename(apiname) != "eric6.bas":
+                    os.path.join(apidir, progLanguage, "*.bas")
+                ) + glob.glob(os.path.join(apidir, progLanguage.lower(), "*.bas")):
+                    if os.path.exists(apiname):
                         os.remove(apiname)
-        
+
+                # remove empty directories
+                with contextlib.suppress(FileNotFoundError, OSError):
+                    os.rmdir(os.path.join(apidir, progLanguage))
+                with contextlib.suppress(FileNotFoundError, OSError):
+                    os.rmdir(os.path.join(apidir, progLanguage.lower()))
+
         if sys.platform == "darwin":
             # delete the Mac app bundle
             uninstallMacAppBundle()
-        
+
         # remove plug-in directories
         removePluginDirectories()
-        
+
         # remove the eric data directory
         removeDataDirectory()
-        
+
         # remove the eric configuration directory
         removeConfigurationData()
-        
+
         print("\nUninstallation completed")
-    except (IOError, OSError) as msg:
-        sys.stderr.write(
-            'Error: {0}\nTry uninstall with admin rights.\n'.format(msg))
+    except OSError as msg:
+        sys.stderr.write("Error: {0}\nTry uninstall with admin rights.\n".format(msg))
         exit(7)
 
 
@@ -206,16 +243,16 @@ def uninstallWindowsLinks():
     Clean up the Desktop and Start Menu entries for Windows.
     """
     try:
-        from pywintypes import com_error        # __IGNORE_WARNING__
+        from pywintypes import com_error  # __IGNORE_WARNING__
     except ImportError:
         # links were not created by install.py
         return
-    
+
     regPath = (
-        "Software\\Microsoft\\Windows\\CurrentVersion\\Explorer" +
-        "\\User Shell Folders"
+        "Software\\Microsoft\\Windows\\CurrentVersion\\Explorer"
+        + "\\User Shell Folders"
     )
-    
+
     # 1. cleanup desktop links
     regName = "Desktop"
     desktopEntry = getWinregEntry(regName, regPath)
@@ -226,22 +263,22 @@ def uninstallWindowsLinks():
             if os.path.exists(linkPath):
                 try:
                     os.remove(linkPath)
-                except EnvironmentError:
+                except OSError:
                     # maybe restrictions prohibited link removal
                     print("Could not remove '{0}'.".format(linkPath))
-    
+
     # 2. cleanup start menu entry
     regName = "Programs"
     programsEntry = getWinregEntry(regName, regPath)
     if programsEntry:
         programsFolder = os.path.normpath(os.path.expandvars(programsEntry))
-        eric6EntryPath = os.path.join(programsFolder, windowsProgramsEntry())
-        if os.path.exists(eric6EntryPath):
+        eric7EntryPath = os.path.join(programsFolder, windowsProgramsEntry())
+        if os.path.exists(eric7EntryPath):
             try:
-                shutil.rmtree(eric6EntryPath)
-            except EnvironmentError:
+                shutil.rmtree(eric7EntryPath)
+            except OSError:
                 # maybe restrictions prohibited link removal
-                print("Could not remove '{0}'.".format(eric6EntryPath))
+                print("Could not remove '{0}'.".format(eric7EntryPath))
 
 
 def uninstallLinuxSpecifics():
@@ -249,38 +286,33 @@ def uninstallLinuxSpecifics():
     Uninstall Linux specific files.
     """
     if os.getuid() == 0:
-        for name in ["/usr/share/pixmaps/eric.png",
-                     "/usr/share/pixmaps/ericWeb.png"]:
-            if os.path.exists(name):
-                os.remove(name)
         for name in [
-            "/usr/share/applications/eric6.desktop",
-            "/usr/share/appdata/eric6.appdata.xml",
-            "/usr/share/metainfo/eric6.appdata.xml",
-            "/usr/share/applications/eric6_browser.desktop",
+            "/usr/share/appdata/eric7.appdata.xml",
+            "/usr/share/metainfo/eric7.appdata.xml",
+            "/usr/share/applications/eric7_browser.desktop",
+            "/usr/share/applications/eric7_ide.desktop",
+            "/usr/share/icons/eric.png",
+            "/usr/share/icons/ericWeb.png",
             "/usr/share/pixmaps/eric.png",
             "/usr/share/pixmaps/ericWeb.png",
-            # from Python2 era
-            "/usr/share/applications/eric6_webbrowser.desktop",
+            # obsolete entries below
+            "/usr/share/applications/eric7.desktop",
         ]:
             if os.path.exists(name):
                 os.remove(name)
     elif os.getuid() >= 1000:
         # it is assumed that user ids start at 1000
-        for name in ["~/.local/share/pixmaps/eric.png",
-                     "~/.local/share/pixmaps/ericWeb.png"]:
-            path = os.path.expanduser(name)
-            if os.path.exists(path):
-                os.remove(path)
         for name in [
-            "~/.local/share/applications/eric6.desktop",
-            "~/.local/share/appdata/eric6.appdata.xml",
-            "~/.local/share/metainfo/eric6.appdata.xml",
-            "~/.local/share/applications/eric6_browser.desktop",
+            "~/.local/share/appdata/eric7.appdata.xml",
+            "~/.local/share/metainfo/eric7.appdata.xml",
+            "~/.local/share/applications/eric7_browser.desktop",
+            "~/.local/share/applications/eric7_ide.desktop",
+            "~/.local/share/icons/eric.png",
+            "~/.local/share/icons/ericWeb.png",
             "~/.local/share/pixmaps/eric.png",
             "~/.local/share/pixmaps/ericWeb.png",
-            # from Python2 era
-            "/usr/share/applications/eric6_webbrowser.desktop",
+            # obsolete entries below
+            "~/.local/share/applications/eric7.desktop",
         ]:
             path = os.path.expanduser(name)
             if os.path.exists(path):
@@ -291,19 +323,18 @@ def uninstallMacAppBundle():
     """
     Uninstall the macOS application bundle.
     """
-    if os.path.exists("/Developer/Applications/Eric6"):
-        shutil.rmtree("/Developer/Applications/Eric6")
+    if os.path.exists("/Developer/Applications/Eric7"):
+        shutil.rmtree("/Developer/Applications/Eric7")
     try:
         macAppBundlePath = getConfig("macAppBundlePath")
         macAppBundleName = getConfig("macAppBundleName")
     except AttributeError:
         macAppBundlePath = defaultMacAppBundlePath
         macAppBundleName = defaultMacAppBundleName
-    for bundlePath in [os.path.join(defaultMacAppBundlePath,
-                                    macAppBundleName),
-                       os.path.join(macAppBundlePath,
-                                    macAppBundleName),
-                       ]:
+    for bundlePath in [
+        os.path.join(defaultMacAppBundlePath, macAppBundleName),
+        os.path.join(macAppBundlePath, macAppBundleName),
+    ]:
         if os.path.exists(bundlePath):
             shutil.rmtree(bundlePath)
 
@@ -313,15 +344,15 @@ def removePluginDirectories():
     Remove the plug-in directories.
     """
     pathsToRemove = []
-    
-    globalPluginsDir = os.path.join(getConfig('mdir'), "eric6plugins")
+
+    globalPluginsDir = os.path.join(getConfig("mdir"), "eric7plugins")
     if os.path.exists(globalPluginsDir):
         pathsToRemove.append(globalPluginsDir)
-    
-    localPluginsDir = os.path.join(getConfigDir(), "eric6plugins")
+
+    localPluginsDir = os.path.join(getConfigDir(), "eric7plugins")
     if os.path.exists(localPluginsDir):
         pathsToRemove.append(localPluginsDir)
-    
+
     if pathsToRemove:
         print("Found these plug-in directories")
         for path in pathsToRemove:
@@ -356,14 +387,18 @@ def removeConfigurationData():
     Remove the eric configuration directory.
     """
     try:
-        from PyQt5.QtCore import QSettings
+        from PyQt6.QtCore import QSettings  # __IGNORE_WARNING_I10__
     except ImportError:
         print("No PyQt variant installed. The configuration directory")
         print("cannot be determined. You have to remove it manually.\n")
         return
-    
-    settings = QSettings(QSettings.IniFormat, QSettings.UserScope,
-                         settingsNameOrganization, settingsNameGlobal)
+
+    settings = QSettings(
+        QSettings.Format.IniFormat,
+        QSettings.Scope.UserScope,
+        settingsNameOrganization,
+        settingsNameGlobal,
+    )
     settingsDir = os.path.dirname(settings.fileName())
     if os.path.exists(settingsDir):
         print("Found the eric configuration directory")
@@ -379,17 +414,17 @@ def removeConfigurationData():
 def getConfigDir():
     """
     Module function to get the name of the directory storing the config data.
-    
+
     @return directory name of the config dir (string)
     """
-    cdn = ".eric6"
+    cdn = ".eric7"
     return os.path.join(os.path.expanduser("~"), cdn)
 
 
 def getWinregEntry(name, path):
     """
     Function to get an entry from the Windows Registry.
-    
+
     @param name variable name
     @type str
     @param path registry path of the variable
@@ -398,10 +433,10 @@ def getWinregEntry(name, path):
     @rtype any
     """
     # From http://stackoverflow.com/a/35286642
-    import winreg
+    import winreg  # __IGNORE_WARNING_I103__
+
     try:
-        registryKey = winreg.OpenKey(winreg.HKEY_CURRENT_USER, path, 0,
-                                     winreg.KEY_READ)
+        registryKey = winreg.OpenKey(winreg.HKEY_CURRENT_USER, path, 0, winreg.KEY_READ)
         value, _ = winreg.QueryValueEx(registryKey, name)
         winreg.CloseKey(registryKey)
         return value
@@ -412,28 +447,30 @@ def getWinregEntry(name, path):
 def windowsDesktopNames():
     """
     Function to generate the link names for the Windows Desktop.
-    
+
     @return list of desktop link names
     @rtype list of str
     """
     majorVersion, minorVersion = sys.version_info[:2]
     linkTemplates = [
-        "eric6 (Python {0}.{1}).lnk",
-        "eric6 Browser (Python {0}.{1}).lnk",
+        "eric7 IDE (Python {0}.{1}).lnk",
+        "eric7 Browser (Python {0}.{1}).lnk",
+        # obsolete entries below
+        "eric7 (Python {0}.{1}).lnk",
     ]
-    
+
     return [ll.format(majorVersion, minorVersion) for ll in linkTemplates]
 
 
 def windowsProgramsEntry():
     """
     Function to generate the name of the Start Menu top entry.
-    
+
     @return name of the Start Menu top entry
     @rtype str
     """
     majorVersion, minorVersion = sys.version_info[:2]
-    return "eric6 (Python {0}.{1})".format(majorVersion, minorVersion)
+    return "eric7 (Python {0}.{1})".format(majorVersion, minorVersion)
 
 
 def main(argv):
@@ -442,8 +479,6 @@ def main(argv):
 
     @param argv list of command line arguments
     """
-    import getopt
-
     initGlobals()
 
     # Parse the command line.
@@ -460,12 +495,12 @@ def main(argv):
     for opt, _arg in optlist:
         if opt == "-h":
             usage(0)
-    
-    print("\nUninstalling eric6 ...")
+
+    print("\nUninstalling eric ...")
     uninstallEric()
     print("\nUninstallation complete.")
     print()
-    
+
     exit(0)
 
 
@@ -475,10 +510,12 @@ if __name__ == "__main__":
     except SystemExit:
         raise
     except Exception:
-        print("""An internal error occured.  Please report all the output of"""
-              """ the program,\n"""
-              """including the following traceback, to"""
-              """ eric-bugs@eric-ide.python-projects.org.\n""")
+        print(
+            """An internal error occured.  Please report all the output of"""
+            """ the program,\n"""
+            """including the following traceback, to"""
+            """ eric-bugs@eric-ide.python-projects.org.\n"""
+        )
         raise
 
 #
